aboutsummaryrefslogtreecommitdiffstats
path: root/Demos/Device/ClassDriver/DualCDC/DualCDC.c
diff options
context:
space:
mode:
Diffstat (limited to 'Demos/Device/ClassDriver/DualCDC/DualCDC.c')
-rw-r--r--Demos/Device/ClassDriver/DualCDC/DualCDC.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/Demos/Device/ClassDriver/DualCDC/DualCDC.c b/Demos/Device/ClassDriver/DualCDC/DualCDC.c
index 82ed59d51..e5406a4ba 100644
--- a/Demos/Device/ClassDriver/DualCDC/DualCDC.c
+++ b/Demos/Device/ClassDriver/DualCDC/DualCDC.c
@@ -163,19 +163,19 @@ void CheckJoystickMovement(void)
}
/** Event handler for the library USB Connection event. */
-void EVENT_USB_Connect(void)
+void EVENT_USB_Device_Connect(void)
{
LEDs_SetAllLEDs(LEDMASK_USB_ENUMERATING);
}
/** Event handler for the library USB Disconnection event. */
-void EVENT_USB_Disconnect(void)
+void EVENT_USB_Device_Disconnect(void)
{
LEDs_SetAllLEDs(LEDMASK_USB_NOTREADY);
}
/** Event handler for the library USB Configuration Changed event. */
-void EVENT_USB_ConfigurationChanged(void)
+void EVENT_USB_Device_ConfigurationChanged(void)
{
LEDs_SetAllLEDs(LEDMASK_USB_READY);
@@ -186,9 +186,9 @@ void EVENT_USB_ConfigurationChanged(void)
LEDs_SetAllLEDs(LEDMASK_USB_ERROR);
}
-/** Event handler for the library USB Unhandled Control Packet event. */
-void EVENT_USB_UnhandledControlPacket(void)
+/** Event handler for the library USB Unhandled Control Request event. */
+void EVENT_USB_Device_UnhandledControlRequest(void)
{
- CDC_Device_ProcessControlPacket(&VirtualSerial1_CDC_Interface);
- CDC_Device_ProcessControlPacket(&VirtualSerial2_CDC_Interface);
+ CDC_Device_ProcessControlRequest(&VirtualSerial1_CDC_Interface);
+ CDC_Device_ProcessControlRequest(&VirtualSerial2_CDC_Interface);
}